@@ -1,6 +1,6 @@
 from __future__ import absolute_import, division, print_function
 
-NUM_VERSION = (2017, 1, 1)
+NUM_VERSION = (2017, 1, 2)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
@@ -22,6 +22,16 @@ class PudbShortcuts(object):
             set_interrupt_handler()
         dbg.set_trace(sys._getframe().f_back)
 
+    @property
+    def go(self):
+        import sys
+        dbg = _get_debugger()
+
+        import threading
+        if isinstance(threading.current_thread(), threading._MainThread):
+            set_interrupt_handler()
+        dbg.set_trace(sys._getframe().f_back, paused=False)
+
 
 if PY3:
     import builtins
@@ -151,14 +161,24 @@ def runcall(*args, **kwds):
     return _get_debugger().runcall(*args, **kwds)
 
 
-def set_trace():
+def set_trace(paused=True):
+    """
+    Start the debugger
+
+    If paused=False (the default is True), the debugger will not stop here
+    (same as immediately pressing 'c' to continue).
+    """
     import sys
     dbg = _get_debugger()
 
     import threading
     if isinstance(threading.current_thread(), threading._MainThread):
         set_interrupt_handler()
-    dbg.set_trace(sys._getframe().f_back)
+
+    dbg.set_trace(sys._getframe().f_back, paused=paused)
+
+
+start = set_trace
 
 
 def _interrupt_handler(signum, frame):
